@@ -19,10 +19,17 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
+import sys
+import traceback
 
 from .errors import *
-from typing import Union
+from random import choice, choices
+from string import digits
 
+class FindPil:
+    found: bool = True
+
+ascii_lowercase = "abcdef"
 
 options = ["dataUri", "flip", "rotate", "scale", "radius", "size", "backgroundColor", "translateX", "translateY"]
 styles = ["adventurer", "adventurer-neutral", "avataaars", "big-ears", "big-ears-neutral",
@@ -31,27 +38,33 @@ styles = ["adventurer", "adventurer-neutral", "avataaars", "big-ears", "big-ears
 styles_depricated = ["female", "gridy", "human", "jdenticon", "male"]
 
 
-class DColor(str):
+class DColor:
     def __init__(self, html_code: str = "#ffffff"):
         """
         Colors used in this package. This uses HTML color codes!
 
         :param html_code: the html color code to use as color
         """
+        if html_code in ["random", "rnd"]:
+            html_code = '#' + ''.join(choices(ascii_lowercase+digits, k=6))
         if not html_code.startswith("#"):
             html_code = "#" + html_code
         if len(html_code) not in [4, 7]:
             raise IncorrectColor(str(html_code))
         self.html_code: str = str(html_code)
-        super().__init__()
 
     def __str__(self):
         return f"{self.html_code}"
     def __repr__(self):
         return f"{self.html_code}"
 
+    @staticmethod
+    def random():
+        html_code = '#' + ''.join(choices(ascii_lowercase + digits, k=6))
+        return DColor(html_code)
 
-class DStyle(str):
+
+class DStyle:
     """
     All possible styles for the avatars. Visit https://avatars.dicebear.com/styles to see what they look like.\n
     - Note: Only works with attributes!
@@ -73,12 +86,14 @@ class DStyle(str):
     personas = styles[14]
     pixel_art = styles[15]
     pixel_art_neutral = styles[16]
+
+    random = choice(styles)
     def __init__(self):
         """Only use `.attribute` to use a style."""
         pass
 
 
-class DFormat(str):
+class DFormat:
     """
     All possible image formats for saving or converting avatars.
     - Note: Only works with attributes!
@@ -117,23 +132,10 @@ class DOptions(dict):
 
 
 
-# class DUrl:
-#     def __init__(self, url: str,):
-#         self._url = url
-#
-#     def __str__(self) -> str:
-#         return str(self._url)
-#     def __repr__(self) -> str:
-#         return str(self._url)
-#     def __eq__(self, other) -> bool:
-#         if isinstance(other, DUrl):
-#             if str(other) == str(self._url):
-#                 return True
-#         return False
-#     def __ne__(self, other) -> bool:
-#         if isinstance(other, (str, DUrl)):
-#             if str(other) != str(self._url):
-#                 return True
-#         return False
-
-
+def pilcheck(func):
+    def wrapper(*args, **kwargs):
+        if FindPil.found is True:
+            return func(*args, **kwargs)
+        else:
+            log_error(PILError())
+    return wrapper
